@@ -31,7 +31,7 @@ Any other distance measure is explicitly named; e.g., ``comoving_distance``.
 
 import logging
 import numpy
-from scipy import interpolate
+from scipy import interpolate, integrate
 import astropy.cosmology
 from astropy import units
 from astropy.cosmology.core import CosmologyError
@@ -340,16 +340,19 @@ class ComovingVolInterpolator(object):
         What parameter to interpolate.
     default_maxz : float, optional
         The maximum z to interpolate up to before falling back to calling
-        astropy directly. Default is 1000.
+        astropy directly. Default is 10.
     numpoints : int, optional
         The number of points to use in the linear interpolation between 0 to 1
-        and 1 to ``default_maxz``. Default is 10000.
+        and 1 to ``default_maxz``. Default is 1000.
+    vol_func: function, optional
+        Optionally set how the volume is calculated by providing a function
     \**kwargs :
         All other keyword args are passed to :py:func:`get_cosmology` to
         select a cosmology. If none provided, will use
         :py:attr:`DEFAULT_COSMOLOGY`.
     """
-    def __init__(self, parameter, default_maxz=10., numpoints=1000, **kwargs):
+    def __init__(self, parameter, default_maxz=10., numpoints=1000,
+                 vol_func=None, **kwargs):
         self.parameter = parameter
         self.numpoints = int(numpoints)
         self.default_maxz = default_maxz
@@ -359,14 +362,18 @@ class ComovingVolInterpolator(object):
         self.nearby_interp = None
         self.faraway_interp = None
         self.default_maxvol = None
+        if vol_func is not None:
+            self.vol_func = vol_func
+        else:
+            self.vol_func = self.cosmology.comoving_volume
+        self.vol_units = self.vol_func(0.5).unit
 
     def _create_interpolant(self, minz, maxz):
-        minlogv = numpy.log(self.cosmology.comoving_volume(minz).value)
-        maxlogv = numpy.log(self.cosmology.comoving_volume(maxz).value)
-        # for computing nearby (z < 1) redshifts
+        minlogv = numpy.log(self.vol_func(minz).value)
+        maxlogv = numpy.log(self.vol_func(maxz).value)
         logvs = numpy.linspace(minlogv, maxlogv, num=self.numpoints)
-        zs = z_at_value(self.cosmology.comoving_volume, numpy.exp(logvs),
-                        units.Mpc**3)
+        zs = z_at_value(self.vol_func, numpy.exp(logvs), self.vol_units)
+
         if self.parameter != 'redshift':
             ys = cosmological_quantity_from_redshift(zs, self.parameter)
         else:
@@ -386,8 +393,7 @@ class ComovingVolInterpolator(object):
         maxz = self.default_maxz
         self.faraway_interp = self._create_interpolant(minz, maxz)
         # store the default maximum volume
-        self.default_maxvol = \
-            numpy.log(self.cosmology.comoving_volume(maxz).value)
+        self.default_maxvol = numpy.log(self.vol_func(maxz).value)
 
     def get_value_from_logv(self, logv):
         """Returns the redshift for the given distance.
@@ -411,8 +417,8 @@ class ComovingVolInterpolator(object):
             # well... check that the logv is finite first
             if not numpy.isfinite(logv).all():
                 raise ValueError("comoving volume must be finite and > 0")
-            zs = z_at_value(self.cosmology.comoving_volume,
-                            numpy.exp(logv[replacemask]), units.Mpc**3)
+            zs = z_at_value(self.vol_func,
+                            numpy.exp(logv[replacemask]), self.vol_units)
             if self.parameter == 'redshift':
                 vals[replacemask] = zs
             else:
@@ -511,6 +517,73 @@ def distance_from_comoving_volume(vc, interp=True, **kwargs):
     return dist
 
 
+def madau_dickinson_2014(z):
+    """ The madau-dickinson 2014 stellar-formation rate
+    """
+    # stellar-formation rate density from https://arxiv.org/pdf/1403.0007.pdf
+    # units are M⊙ year−1 Mpc−3
+    val = 0.015 * (1 + z) ** 2.7 / (1 + ((1 + z) / 2.9) ** 5.6)
+    return val * units.year ** -1 * units.Mpc**3 * units.solMass
+
+
+def rate_from_redshift(z, rate_density, **kwargs):
+    """Total rate of occurances out to some redshift
+
+    Parameters
+    ----------
+    z : float
+        The redshift.
+    rate_density : function
+        The rate density per unit volume as a function of redshift.
+    \**kwargs :
+        All other keyword args are passed to :py:func:`get_cosmology` to
+        select a cosmology. If none provided, will use
+        :py:attr:`DEFAULT_COSMOLOGY`.
+
+    Returns
+    -------
+    rate: float
+        The total rate of occurances out to some redshift
+    """
+    cosmology = get_cosmology(**kwargs)
+    def diff_rate(z):
+        dr = cosmology.differential_comoving_volume(z) / (1 + z)
+        return (dr * 4 * numpy.pi * rate_density(z)).value
+    return integrate.quad(diff_rate, 0, z)[0]
+
+
+def distance_from_rate(vc, rate_density, **kwargs):
+    r"""Returns the luminosity distance from the given total rate value
+
+    Parameters
+    ----------
+    vc : float
+        The total rate
+    \**kwargs :
+        All other keyword args are passed to :py:func:`get_cosmology` to
+        select a cosmology. If none provided, will use
+        :py:attr:`DEFAULT_COSMOLOGY`.
+
+    Returns
+    -------
+    float :
+        The luminosity distance at the given comoving volume.
+    """
+    cosmology = get_cosmology(**kwargs)
+    if not hasattr(rate_density, 'dist_interp'):
+        rate_density.dist_interp = {}
+
+    if cosmology.name not in rate_density.dist_interp:
+        def rate_func(z):
+            return rate_from_redshift(z, rate_density) * rate_density(0.5).unit
+
+        rate_density.dist_interp[cosmology.name] = ComovingVolInterpolator(
+                                        'luminosity_distance',
+                                        vol_func=rate_func,
+                                        cosmology=cosmology)
+    return rate_density.dist_interp[cosmology.name](vc)
+
+
 def cosmological_quantity_from_redshift(z, quantity, strip_unit=True,
                                         **kwargs):
     r"""Returns the value of a cosmological quantity (e.g., age) at a redshift.
@@ -543,7 +616,7 @@ def cosmological_quantity_from_redshift(z, quantity, strip_unit=True,
     return val
 
 
-__all__ = ['redshift', 'redshift_from_comoving_volume',
-           'distance_from_comoving_volume',
+__all__ = ['rate_from_redshift', 'redshift', 'redshift_from_comoving_volume',
+           'distance_from_comoving_volume', 'distance_from_rate',
            'cosmological_quantity_from_redshift',
            ]
